from HardenedSteel.globals                                      \
    import get_system_random


from HardenedSteel.facades.integers.random_number_generation    \
    import                                                      \
    generate_signed_integer,                                    \
    generate_unsigned_integer
