from HardenedSteel.globals.singletons.SingletonSystenRandom     \
    import                                                      \
    get_system_random,                                          \
    set_system_random
