from HardenedSteel.globals.singletons               \
    import                                          \
    get_system_random,                              \
    set_system_random

from HardenedSteel.globals.vars                     \
    import                                          \
    get_maximum_size_of_integer,                    \
    get_zero,                                       \
    get_one,                                        \
    get_minimum_size_of_integer,                    \
    get_maximum_size_of_unsigned_integer
