from HardenedSteel.facades.texts.random_text_generation     \
    import                                                  \
    generate_lowercase_label_by_size,                       \
    generate_uppercase_label_by_size,                       \
    generate_label_by_size

