from HardenedSteel.globals                                      \
    import                                                      \
    get_system_random,                                          \
    get_one

from HardenedSteel.facades.booleans.random_boolean_generation   \
    import generate_random_boolean
