from sys                                            \
    import maxsize

from HardenedSteel.globals.vars.integer             \
    import                                          \
    get_maximum_size_of_integer,                    \
    get_zero,                                       \
    get_minimum_size_of_integer,                    \
    get_maximum_size_of_unsigned_integer,           \
    get_one
